@@ -69,7 +69,6 @@ void	voice_send(void)
 		fread ((char *)&send_pkt, 56, 1, in_dat);
         	if (send_pkt.B_header.seq == 0x80)
         	{
-                //	fread ((char *)&send_pkt, 56, 1, in_dat);
                 	ConSend();
                 	ConnectWait = TRUE;
 			AckTimeOut = 0;
@@ -262,8 +261,6 @@ int main(int argc, const char **argv){
 	int    numrcv;
 	int	cmdin;
 
-	FILE	*dat;
-
         signal(SIGINT,CloseSocket);
         signal(SIGTERM,CloseSocket);
 
@@ -402,11 +399,7 @@ int main(int argc, const char **argv){
                                 if (ConnectWait)
                                 {
                                         AckTimeOut++;
-                                        if (AckTimeOut == 20)   /* 100 m sec, */
-                                        {
-                                                ConSend();
-                                        }
-                                        if (AckTimeOut > 40)    /* 200 m sec. */
+                                        if (AckTimeOut > 100)    /* 500 m sec. */
                                         {
                                                 RelaySW = TRUE;
                                                 ConnectWait = FALSE;
@@ -417,6 +410,10 @@ int main(int argc, const char **argv){
                                                 fprintf (logfile, "%24.24s Change to Relay Mode\n", ctime(&now));
 						fclose (logfile);
                                         }
+                                        else if ((AckTimeOut % 20) == 0)   /* 100 m sec, interval */
+                                        {
+                                                ConSend();
+                                        }
 				}
 				if (DVwait)
 				{
@@ -541,7 +538,7 @@ int main(int argc, const char **argv){
 						{
 							memcpy (&CallerCall, &send_packet.header.MyCall, 8);
 							fwrite ((char *)&send_packet, 56, 1, dat);
-							audio_msg(CallerCall, client_call);
+							audio_msg(CallerCall, client_call, send_packet);
 						}
 						else 
                                                         fwrite ((char *)&send_packet, 56, 1, dat);
